@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2011 Nokia Corporation and/or its subsidiary(-ies).
+** Copyright (C) 2012 Nokia Corporation and/or its subsidiary(-ies).
 ** All rights reserved.
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
@@ -46,7 +46,13 @@ int main(int argc, char *argv[])
 {
     QApplication app(argc, argv);
     MainWindow window;
+#if defined(Q_OS_SYMBIAN)
+    window.showMaximized();
+#elif defined(Q_WS_MAEMO_5)
+    window.show();
+#else
     window.resize(640, 480);
     window.show();
+#endif
     return app.exec();
 }
