@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2011 Nokia Corporation and/or its subsidiary(-ies).
+** Copyright (C) 2012 Nokia Corporation and/or its subsidiary(-ies).
 ** All rights reserved.
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
@@ -51,7 +51,7 @@ FtpWindow::FtpWindow(QWidget *parent)
     ftpServerLabel->setBuddy(ftpServerLineEdit);
 
     statusLabel = new QLabel(tr("Please enter the name of an FTP server."));
-#ifdef Q_OS_SYMBIAN
+#if defined(Q_OS_SYMBIAN) || defined(Q_WS_MAEMO_5) || defined(Q_WS_SIMULATOR)
     // Use word wrapping to fit the text on screen
     statusLabel->setWordWrap( true );
 #endif
@@ -114,29 +114,6 @@ FtpWindow::FtpWindow(QWidget *parent)
     mainLayout->addWidget(buttonBox);
     setLayout(mainLayout);
 
-    QNetworkConfigurationManager manager;
-    if (manager.capabilities() & QNetworkConfigurationManager::NetworkSessionRequired) {
-        // Get saved network configuration
-        QSettings settings(QSettings::UserScope, QLatin1String("Trolltech"));
-        settings.beginGroup(QLatin1String("QtNetwork"));
-        const QString id = settings.value(QLatin1String("DefaultNetworkConfiguration")).toString();
-        settings.endGroup();
-
-        // If the saved network configuration is not currently discovered use the system default
-        QNetworkConfiguration config = manager.configurationFromIdentifier(id);
-        if ((config.state() & QNetworkConfiguration::Discovered) !=
-            QNetworkConfiguration::Discovered) {
-            config = manager.defaultConfiguration();
-        }
-
-        networkSession = new QNetworkSession(config, this);
-        connect(networkSession, SIGNAL(opened()), this, SLOT(enableConnectButton()));
-
-        connectButton->setEnabled(false);
-        statusLabel->setText(tr("Opening network session."));
-        networkSession->open();
-    }
-
     setWindowTitle(tr("FTP"));
 }
 
@@ -169,6 +146,37 @@ void FtpWindow::connectOrDisconnect()
     setCursor(Qt::WaitCursor);
 #endif
 
+    if (!networkSession || !networkSession->isOpen()) {
+        if (manager.capabilities() & QNetworkConfigurationManager::NetworkSessionRequired) {
+            if (!networkSession) {
+                // Get saved network configuration
+                QSettings settings(QSettings::UserScope, QLatin1String("Trolltech"));
+                settings.beginGroup(QLatin1String("QtNetwork"));
+                const QString id = settings.value(QLatin1String("DefaultNetworkConfiguration")).toString();
+                settings.endGroup();
+
+                // If the saved network configuration is not currently discovered use the system default
+                QNetworkConfiguration config = manager.configurationFromIdentifier(id);
+                if ((config.state() & QNetworkConfiguration::Discovered) !=
+                    QNetworkConfiguration::Discovered) {
+                    config = manager.defaultConfiguration();
+                }
+
+                networkSession = new QNetworkSession(config, this);
+                connect(networkSession, SIGNAL(opened()), this, SLOT(connectToFtp()));
+                connect(networkSession, SIGNAL(error(QNetworkSession::SessionError)), this, SLOT(enableConnectButton()));
+            }
+            connectButton->setEnabled(false);
+            statusLabel->setText(tr("Opening network session."));
+            networkSession->open();
+            return;
+        }
+    }
+    connectToFtp();
+}
+
+void FtpWindow::connectToFtp()
+{
 //![1]
     ftp = new QFtp(this);
     connect(ftp, SIGNAL(commandFinished(int,bool)),
@@ -407,7 +415,7 @@ void FtpWindow::enableConnectButton()
     settings.setValue(QLatin1String("DefaultNetworkConfiguration"), id);
     settings.endGroup();
 
-    connectButton->setEnabled(networkSession->isOpen());
+    connectButton->setEnabled(true);
     statusLabel->setText(tr("Please enter the name of an FTP server."));
 }
 
