@@ -1,40 +1,39 @@
 /****************************************************************************
 **
-** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** Copyright (C) 2012 Nokia Corporation and/or its subsidiary(-ies).
 ** All rights reserved.
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
 ** This file is part of the examples of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in
-** accordance with the Qt Commercial License Agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Nokia.
+** $QT_BEGIN_LICENSE:BSD$
+** You may use this file under the terms of the BSD license as follows:
 **
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** "Redistribution and use in source and binary forms, with or without
+** modification, are permitted provided that the following conditions are
+** met:
+**   * Redistributions of source code must retain the above copyright
+**     notice, this list of conditions and the following disclaimer.
+**   * Redistributions in binary form must reproduce the above copyright
+**     notice, this list of conditions and the following disclaimer in
+**     the documentation and/or other materials provided with the
+**     distribution.
+**   * Neither the name of Nokia Corporation and its Subsidiary(-ies) nor
+**     the names of its contributors may be used to endorse or promote
+**     products derived from this software without specific prior written
+**     permission.
 **
-** In addition, as a special exception, Nokia gives you certain additional
-** rights.  These rights are described in the Nokia Qt LGPL Exception
-** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
-**
-** If you have questions regarding the use of this file, please contact
-** Nokia at qt-info@nokia.com.
+** THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+** "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+** LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
+** A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
+** OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
+** SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
+** LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+** DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
+** THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+** (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
+** OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE."
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -75,7 +74,11 @@ Window::Window()
 //! [2]
     penWidthSpinBox = new QSpinBox;
     penWidthSpinBox->setRange(0, 20);
+#if defined(Q_OS_SYMBIAN) || defined(Q_WS_MAEMO_5) || defined(Q_WS_SIMULATOR)
+    penWidthSpinBox->setSpecialValueText(tr("0"));
+#else
     penWidthSpinBox->setSpecialValueText(tr("0 (cosmetic pen)"));
+#endif
 
     penWidthLabel = new QLabel(tr("Pen &Width:"));
     penWidthLabel->setBuddy(penWidthSpinBox);
@@ -135,12 +138,12 @@ Window::Window()
     brushStyleComboBox->addItem(tr("Dense 7"), Qt::Dense7Pattern);
     brushStyleComboBox->addItem(tr("None"), Qt::NoBrush);
 
-    brushStyleLabel = new QLabel(tr("&Brush Style:"));
+    brushStyleLabel = new QLabel(tr("&Brush:"));
     brushStyleLabel->setBuddy(brushStyleComboBox);
 //! [4]
 
 //! [5]
-    otherOptionsLabel = new QLabel(tr("Other Options:"));
+    otherOptionsLabel = new QLabel(tr("Options:"));
 //! [5] //! [6]
     antialiasingCheckBox = new QCheckBox(tr("&Antialiasing"));
 //! [6] //! [7]
@@ -169,26 +172,27 @@ Window::Window()
 //! [9]
     QGridLayout *mainLayout = new QGridLayout;
 //! [9] //! [10]
+#if defined(Q_OS_SYMBIAN) || defined(Q_WS_MAEMO_5) || defined(Q_WS_SIMULATOR)
+    mainLayout->setSizeConstraint(QLayout::SetNoConstraint);
+#endif
     mainLayout->setColumnStretch(0, 1);
     mainLayout->setColumnStretch(3, 1);
     mainLayout->addWidget(renderArea, 0, 0, 1, 4);
-    mainLayout->setRowMinimumHeight(1, 6);
-    mainLayout->addWidget(shapeLabel, 2, 1, Qt::AlignRight);
-    mainLayout->addWidget(shapeComboBox, 2, 2);
-    mainLayout->addWidget(penWidthLabel, 3, 1, Qt::AlignRight);
-    mainLayout->addWidget(penWidthSpinBox, 3, 2);
-    mainLayout->addWidget(penStyleLabel, 4, 1, Qt::AlignRight);
-    mainLayout->addWidget(penStyleComboBox, 4, 2);
-    mainLayout->addWidget(penCapLabel, 5, 1, Qt::AlignRight);
-    mainLayout->addWidget(penCapComboBox, 5, 2);
-    mainLayout->addWidget(penJoinLabel, 6, 1, Qt::AlignRight);
-    mainLayout->addWidget(penJoinComboBox, 6, 2);
-    mainLayout->addWidget(brushStyleLabel, 7, 1, Qt::AlignRight);
-    mainLayout->addWidget(brushStyleComboBox, 7, 2);
-    mainLayout->setRowMinimumHeight(8, 6);
-    mainLayout->addWidget(otherOptionsLabel, 9, 1, Qt::AlignRight);
-    mainLayout->addWidget(antialiasingCheckBox, 9, 2);
-    mainLayout->addWidget(transformationsCheckBox, 10, 2);
+    mainLayout->addWidget(shapeLabel, 2, 0, Qt::AlignRight);
+    mainLayout->addWidget(shapeComboBox, 2, 1);
+    mainLayout->addWidget(penWidthLabel, 3, 0, Qt::AlignRight);
+    mainLayout->addWidget(penWidthSpinBox, 3, 1);
+    mainLayout->addWidget(penStyleLabel, 4, 0, Qt::AlignRight);
+    mainLayout->addWidget(penStyleComboBox, 4, 1);
+    mainLayout->addWidget(penCapLabel, 3, 2, Qt::AlignRight);
+    mainLayout->addWidget(penCapComboBox, 3, 3);
+    mainLayout->addWidget(penJoinLabel, 2, 2, Qt::AlignRight);
+    mainLayout->addWidget(penJoinComboBox, 2, 3);
+    mainLayout->addWidget(brushStyleLabel, 4, 2, Qt::AlignRight);
+    mainLayout->addWidget(brushStyleComboBox, 4, 3);
+    mainLayout->addWidget(otherOptionsLabel, 5, 0, Qt::AlignRight);
+    mainLayout->addWidget(antialiasingCheckBox, 5, 1, 1, 1, Qt::AlignRight);
+    mainLayout->addWidget(transformationsCheckBox, 5, 2, 1, 2, Qt::AlignRight);
     setLayout(mainLayout);
 
     shapeChanged();
