@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
+** Copyright (C) 2012 Nokia Corporation and/or its subsidiary(-ies).
 ** All rights reserved.
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
@@ -43,7 +43,11 @@
 #include "imagecomposer.h"
 
 //! [0]
+#if defined(Q_OS_SYMBIAN) || defined(Q_WS_SIMULATOR)
+static const QSize resultSize(50, 50);
+#else
 static const QSize resultSize(200, 200);
+#endif
 //! [0]
 
 //! [1]
@@ -104,7 +108,10 @@ ImageComposer::ImageComposer()
     mainLayout->addWidget(destinationButton, 0, 2, 3, 1);
     mainLayout->addWidget(equalLabel, 1, 3);
     mainLayout->addWidget(resultLabel, 0, 4, 3, 1);
+#if defined(Q_OS_SYMBIAN) || defined(Q_WS_MAEMO_5) || defined(Q_WS_SIMULATOR)
+#else
     mainLayout->setSizeConstraint(QLayout::SetFixedSize);
+#endif
     setLayout(mainLayout);
 //! [4]
 
@@ -176,6 +183,9 @@ void ImageComposer::loadImage(const QString &fileName, QImage *image,
 {
     image->load(fileName);
 
+    // Scale the image to given size
+    *image = image->scaled(resultSize, Qt::KeepAspectRatio);
+
     QImage fixedImage(resultSize, QImage::Format_ARGB32_Premultiplied);
     QPainter painter(&fixedImage);
     painter.setCompositionMode(QPainter::CompositionMode_Source);
