@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2011 Nokia Corporation and/or its subsidiary(-ies).
+** Copyright (C) 2012 Nokia Corporation and/or its subsidiary(-ies).
 ** All rights reserved.
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
@@ -79,5 +79,10 @@ int main(int argc, char **argv)
         qWarning() << "line" << lineNo << ":" << result.toString();
     }
 
+#if defined(Q_OS_SYMBIAN)
+    listWidget.showMaximized();
+#else
+    listWidget.show();
+#endif
     return app.exec();
 }
