@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2011 Nokia Corporation and/or its subsidiary(-ies).
+** Copyright (C) 2012 Nokia Corporation and/or its subsidiary(-ies).
 ** All rights reserved.
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
@@ -120,7 +120,7 @@ int main(int argc, char *argv[])
     QScriptValue tetrix = ctor.construct(QScriptValueList() << scriptUi);
 //! [3]
 
-    QPushButton *debugButton = qFindChild<QPushButton*>(ui, "debugButton");
+    QPushButton *debugButton = ui->findChild<QPushButton*>("debugButton");
 #if !defined(QT_NO_SCRIPTTOOLS)
     QObject::connect(debugButton, SIGNAL(clicked()),
                      debugger.action(QScriptEngineDebugger::InterruptAction),
