@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2011 Nokia Corporation and/or its subsidiary(-ies).
+** Copyright (C) 2012 Nokia Corporation and/or its subsidiary(-ies).
 ** All rights reserved.
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
@@ -49,9 +49,9 @@ TextFinder::TextFinder(QWidget *parent)
     QWidget *formWidget = loadUiFile();
 
 //! [1]
-    ui_findButton = qFindChild<QPushButton*>(this, "findButton");
-    ui_textEdit = qFindChild<QTextEdit*>(this, "textEdit");
-    ui_lineEdit = qFindChild<QLineEdit*>(this, "lineEdit");
+    ui_findButton = findChild<QPushButton*>("findButton");
+    ui_textEdit = findChild<QTextEdit*>("textEdit");
+    ui_lineEdit = findChild<QLineEdit*>("lineEdit");
 //! [0] //! [1]
 
 //! [2]
